import tatsumaki.wrapper
import tatsumaki.data_structures
import tatsumaki.error

wrapper = tatsumaki.wrapper
data_structures = tatsumaki.data_structures
error = tatsumaki.error

__all__ = [
    'wrapper',
]

name = "tatsumaki.py"
version = "0.3"
